@@ -285,7 +285,7 @@ class NFSv3(RPC):
         return unpacker.unpack_link3res()
 
     @fh_check
-    def readdir(self, dir_handle, cookie=0, cookie_verf='0', count=4096, auth=None):
+    def readdir(self, dir_handle, cookie=0, cookie_verf=b'0', count=4096, auth=None):
         packer = nfs_pro_v3Packer()
         packer.pack_readdir3args(readdir3args(dir=nfs_fh3(dir_handle),
                                               cookie=cookie,
@@ -299,7 +299,7 @@ class NFSv3(RPC):
         return unpacker.unpack_readdir3res()
 
     @fh_check
-    def readdirplus(self, dir_handle, cookie=0, cookie_verf='0', dircount=4096, maxcount=32768, auth=None):
+    def readdirplus(self, dir_handle, cookie=0, cookie_verf=b'0', dircount=4096, maxcount=32768, auth=None):
         packer = nfs_pro_v3Packer()
         packer.pack_readdirplus3args(readdirplus3args(dir=nfs_fh3(dir_handle),
                                                       cookie=cookie,
